@@ -36,7 +36,7 @@ use strict;
 our @ISA = qw(Exporter);
 our @EXPORT = qw( setup_conntrack );
 our @EXPORT_OK = qw( handle_helper_rule );
-our $VERSION = '4.6_12';
+our $VERSION = '4.6_10';
 
 our %valid_ctevent = ( new        => 1,
 		       related    => 1,
@@ -278,8 +278,9 @@ sub process_format( $ ) {
 sub setup_conntrack($) {
     my $convert = shift;
     my $fn;
+    my @files = $convert ? ( qw/notrack conntrack/ ) : ( 'conntrack' );
 
-    for my $name ( qw/notrack conntrack/ ) {
+    for my $name ( @files ) {
 
 	$fn = open_file( $name, 3 , 1 );
 
